@@ -40,9 +40,9 @@
 namespace muFFT {
   namespace version {
 
-    constexpr bool git_dirty{true};
-    constexpr char git_describe[]{"0.9.2-dirty"};
-    constexpr char git_hash[]{"4ac0a714bdf614d06ed3af938a9e9060cef29dc7"};
+    constexpr bool git_dirty{false};
+    constexpr char git_describe[]{"0.9.3"};
+    constexpr char git_hash[]{"6da87a38dd9b5cdfa1bc026090d97130043b8c0b"};
 
     //------------------------------------------------------------------------//
     std::string info() {
